(get-comment this)(get-comment this args)(get-comment this args httpc-opts)Retrieves one comment resource. Requires :blog-id, :post-id, and
:comment-id be provided in the args map.
Retrieves one comment resource. Requires `:blog-id`, `:post-id`, and `:comment-id` be provided in the `args` map.
(unpublish-post this)(unpublish-post this args)(unpublish-post this args httpc-opts)Moves a post back to the draft state. Requires :blog-id and :post-id
be provided in the args map.
Moves a post back to the draft state. Requires `:blog-id` and `:post-id` be provided in the `args` map.
(get-user-blog this)(get-user-blog this args)(get-user-blog this args httpc-opts)Gets one blog and user info pair. Requires :user-id and :blog-id be
provided in the args map.
Gets one blog and user info pair. Requires `:user-id` and `:blog-id` be provided in the `args` map.
(update-post this)(update-post this args)(update-post this args httpc-opts)Updates a post. Requires :blog-id and :post-id be provided in the
args map.
Updates a post. Requires `:blog-id` and `:post-id` be provided in the `args` map.
(approve-comment this)(approve-comment this args)(approve-comment this args httpc-opts)Marks a comment as approved. Requires :blog-id, :post-id, and
:comment-id be provided in the args map.
Marks a comment as approved. Requires `:blog-id`, `:post-id`, and `:comment-id` be provided in the `args` map.
(get-pages this)(get-pages this args)(get-pages this args httpc-opts)Retrieves the list of pages for a blog. Requires :blog-id be provided
in the args map.
Retrieves the list of pages for a blog. Requires `:blog-id` be provided in the `args` map.
(get-user this)(get-user this args)(get-user this args httpc-opts)Retrieves a user. Requires :user-id be provided in the args map.
Retrieves a user. Requires `:user-id` be provided in the `args` map.
(spam-comment this)(spam-comment this args)(spam-comment this args httpc-opts)Marks a comment as spam, hiding it from the default comment rendering.
Requires :blog-id, :post-id, and :comment-id be provided in the
args map.
Marks a comment as spam, hiding it from the default comment rendering. Requires `:blog-id`, `:post-id`, and `:comment-id` be provided in the `args` map.
(remove-comment-content this)(remove-comment-content this args)(remove-comment-content this args httpc-opts)Removes the content of a comment. Requires :blog-id, :post-id, and
:comment-id be provided in the args map.
Removes the content of a comment. Requires `:blog-id`, `:post-id`, and `:comment-id` be provided in the `args` map.
(get-user-posts this)(get-user-posts this args)(get-user-posts this args httpc-opts)Retrieves a list of post and post user info pairs, possibly filtered. The
post user info contains per-user information about the post, such as access
rights, specific to the user. Requires :user-id and :blog-id :post-id
be provided in the args map.
Retrieves a list of post and post user info pairs, possibly filtered. The post user info contains per-user information about the post, such as access rights, specific to the user. Requires `:user-id` and `:blog-id` `:post-id` be provided in the `args` map.
(delete-comment this)(delete-comment this args)(delete-comment this args httpc-opts)Deletes a comment. Requires :blog-id, :post-id, and :comment-id be
provided in the args map.
Deletes a comment. Requires `:blog-id`, `:post-id`, and `:comment-id` be provided in the `args` map.
(get-post this)(get-post this args)(get-post this args httpc-opts)Retrieves one post. Requires :blog-id. Additionally, either :post-id
or :path must be provided in the args map.
Retrieves one post. Requires `:blog-id`. Additionally, either `:post-id` or `:path` must be provided in the `args` map.
(get-comments this)(get-comments this args)(get-comments this args httpc-opts)Retrieves comments. Requires :blog-id be provided in the args map. If
a :post-id is also provided, returns just the comments for that post. If
not, returns all comments for the blog.
Retrieves comments. Requires `:blog-id` be provided in the `args` map. If a `:post-id` is also provided, returns just the comments for that post. If not, returns all comments for the blog.
(delete-post this)(delete-post this args)(delete-post this args httpc-opts)Deletes a post. Requires :blog-id and :post-id be provided in the
args map.
Deletes a post. Requires `:blog-id` and `:post-id` be provided in the `args` map.
(get-page this)(get-page this args)(get-page this args httpc-opts)Retrieves one pages resource. Requires :blog-id and :page-id be
provided in the args map.
Retrieves one pages resource. Requires `:blog-id` and `:page-id` be provided in the `args` map.
(publish-post this)(publish-post this args)(publish-post this args httpc-opts)Publishes a post. Requires :blog-id and :post-id be provided in the
args map.
Publishes a post. Requires `:blog-id` and `:post-id` be provided in the `args` map.
(get-pageviews this)(get-pageviews this args)(get-pageviews this args httpc-opts)Retrieve pageview stats for a Blog. Requires :blog-id be provided in the
args map.
Retrieve pageview stats for a Blog. Requires `:blog-id` be provided in the `args` map.
(update-page this)(update-page this args)(update-page this args httpc-opts)Updates a page. :blog-id and :page-id be provided in the args map.
Updates a page. `:blog-id` and `:page-id` be provided in the `args` map.
(get-blogs this)(get-blogs this args)(get-blogs this args httpc-opts)Retrieves a list of blogs. Requires :user-id be provided in the args
map.
Retrieves a list of blogs. Requires `:user-id` be provided in the `args` map.
(search this)(search this args)(search this args httpc-opts)Searches for a post that matches the given query terms. Requires
:blod-id and :query be provided in the args map. The vallue for
:query is simply a search string, as you would type it in the search
box for a Blogger-hosted site.
Searches for a post that matches the given query terms. Requires `:blod-id` and `:query` be provided in the `args` map. The vallue for `:query` is simply a search string, as you would type it in the search box for a Blogger-hosted site.
(get-posts this)(get-posts this args)(get-posts this args httpc-opts)Retrieves a list of posts. Requires :blog-id be provided in the args
map.
Retrieves a list of posts. Requires `:blog-id` be provided in the `args` map.
(add-page this)(add-page this args)(add-page this args httpc-opts)Adds a page. Requires :blog-id be provided in the args map.
Adds a page. Requires `:blog-id` be provided in the `args` map.
(delete-page this)(delete-page this args)(delete-page this args httpc-opts)Deletes a page. Requires :blog-id and :page-id be provided in the
args map.
Deletes a page. Requires `:blog-id` and `:page-id` be provided in the `args` map.
(get-user-post this)(get-user-post this args)(get-user-post this args httpc-opts)Gets one post and user info pair. Requires :user-id, :blog-id, and
:post-id be provided in the args map.
Gets one post and user info pair. Requires `:user-id`, `:blog-id`, and `:post-id` be provided in the `args` map.
(get-blog this)(get-blog this args)(get-blog this args httpc-opts)Retrieves a blog. Either a :blog-id or a :url needs to be
provided in the args map.
Retrieves a blog. Either a `:blog-id` or a `:url` needs to be provided in the `args` map.
(add-post this)(add-post this args)(add-post this args httpc-opts)Adds a post. Requires :blog-id be provided in the args map.
Adds a post. Requires `:blog-id` be provided in the `args` map.
(create-client)(create-client opts)Constructor for the Blogger client. Optionally takes a map that may contain
any of the :blog-id, :post-id, or :user-id keys and associated values.
Values of these keys will be used in API calls if the call itself does not
provide them.
Constructor for the Blogger client. Optionally takes a map that may contain any of the `:blog-id`, `:post-id`, or `:user-id` keys and associated values. Values of these keys will be used in API calls if the call itself does not provide them.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |